l_heure_de_catherine

package module
v0.0.0-...-34cf7a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2024 License: MIT Imports: 11 Imported by: 0

README

L'heure de Catherine (Catherine's hour)

I'm a simple bot for bluesky (https://bsky.app/profile/lheure2catherine.bsky.social).
I'm just publishing a message saying "C'est l'heure de Catherine".
I'm running on a GCP Cloud Run functions triggered by a Cloud Scheduler through a Pub/Sub topics event.

Configuration

I'm using the Secret Manager to store the credentials.
It needs to be mounted as a file with this path: /mnt/credential

The file is a json file with the same payload used by the com.atproto.server.createSession endpoint.
It should look like this:

{
    "identifier": "a bluesky handle",
    "password": "(app) password of the account"
}

You should use an "app password" as this will limit the possible action I could make (yes I can only post a fixed message).

Command

I have a simple command which mostly allow to locally test myself and validate that the credential are good.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MidiSix

func MidiSix(ctx context.Context, _ event.Event) error

Types

This section is empty.

Directories

Path Synopsis

Jump to